@@ -1,11 +1,13 @@
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 
 from tarexp.dataset import Dataset, SparseVectorDataset, TaskFeeder
 from tarexp.workflow import Workflow, WorkflowReplay, \
                             OnePhaseTARWorkflow, OnePhaseTARWorkflowReplay, \
                             TwoPhaseTARWorkflow
 from tarexp.ledger import Ledger, FrozenLedger
-from tarexp.experiments import TARExperiment, StoppingExperimentOnReplay, createDFfromResults
+from tarexp.experiments import TARExperiment, StoppingExperimentOnReplay
 from tarexp.evaluation import OptimisticCost
 
-from tarexp.util import readObj, saveObj
\ No newline at end of file
+from tarexp.util import readObj, saveObj
+
+from tarexp import helper
